@@ -15,6 +15,7 @@ import sys
 import string
 
 import pandas as pd
+import xlsxwriter
 
 from gridsource import Data, IOData, ValidData, __version__
 from gridsource.io import DEFAULT_EXCEL_ENGINE
@@ -27,6 +28,7 @@ def version(args=None):
         msg += "\n  * Python Version: %s" % sys.version
         msg += "\n  * Python: %s" % sys.executable
         msg += "\n  * Pandas: %s" % pd.__version__
+        msg += "\n  * xlsxwriter: %s" % xlsxwriter.__version__
     print(msg)
 
 
@@ -92,9 +94,8 @@ def parse_args(args):
     # https://docs.python.org/3/library/argparse.html
     # https://docs.python.org/3/howto/argparse.html
     parser = argparse.ArgumentParser("gsource")
-    parser.add_argument(
-        "-v", "--verbose", action="store_true", help="Show Version and exit"
-    )
+    parser.add_argument("--version", action="store_true", help="Show Version and exit")
+    parser.add_argument("-v", "--verbose", action="store_true")
     parser.set_defaults(process=version)
 
     subparsers = parser.add_subparsers(help="sub-command help")
